"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Text = exports.H5 = exports.H4 = exports.H3 = exports.H2 = exports.H1 = exports.GridSection = exports.Section = void 0;

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _variables = require("./variables");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

/**
 * Exporting Styled Components
 */

/** ************************************************/

/** ***************** DIV STYLING *****************/

/** ************************************************/

/**
 * Section Component
 * @type Section
 *
 * @prop {string} bg: custom HEXCODE (#FFFFFF)
 * @prop {string} bgGradient: use gradient for background?
 * @prop {string} borderRadius: use gradient for background?
 * @prop {boolean} align: align text to center?
 * @prop {string} padding: add padding to section
 */
var Section = _styledComponents.default.section.withConfig({
  displayName: "global__Section",
  componentId: "wozf93-0"
})(["background:", ";border-radius:", ";text-align:", ";padding:", ";"], function (props) {
  return props.bgGradient ? "linear-gradient(".concat(props.bgGradient, ")") : props.bg ? props.bg : 'none';
}, function (props) {
  return props.borderRadius;
}, function (props) {
  return props.align;
}, function (props) {
  return props.padding;
});
/**
 * GridSection Component
 * @extends Section
 *
 * @prop {string} split: split columns with this config
 * @prop {string} tabletSplit: add split to section (on tablet)
 * @prop {string} mobileSplit: split columns (on mobile)
 * @prop {string} gap: add grid-gap (gutter)
 * @prop {string} tabletGap: add gap to section (on tablet)
 * @prop {string} width: set grid section width
 * @prop {string} tabletWidth: add width to section (on tablet)
 * @prop {string} mobileWidth: set width (on mobile)
 * @prop {string} margin: sets margin to the Grid Section
 * @prop {string} padding: add padding to section
 * @prop {string} mobilePadding: add padding to section (on mobile)
 * @prop {string} tabletPadding: add padding to section (on tablet)
 * @prop {boolean} alignVertically: align items vertically centered?
 * @prop {boolean} alignBottom: align items to bottom?
 * @prop {boolean} justifyCenter: justifies all the children center
 * @prop {boolean} sameHeightChildren: set same height to all children
 */


exports.Section = Section;
var GridSection = (0, _styledComponents.default)(Section).withConfig({
  displayName: "global__GridSection",
  componentId: "wozf93-1"
})(["display:grid;grid-template-columns:", ";grid-gap:", ";grid-auto-rows:", ";width:", ";margin:", ";align-items:", ";justify-items:", ";@media screen and (max-width:1280px){padding:", ";width:", ";grid-template-columns:", ";grid-gap:", ";}@media screen and (max-width:824px){padding:", ";grid-template-columns:", ";grid-gap:", ";width:", ";}"], function (props) {
  return props.split ? props.split : '1fr 1fr';
}, function (props) {
  return props.gap ? props.gap : '0';
}, function (props) {
  return props.sameHeightChildren ? '1fr' : 'auto';
}, function (props) {
  return props.width ? "".concat(props.width, "%") : 'auto';
}, function (props) {
  return props.margin ? props.margin : props.width ? '0 auto' : 'auto';
}, function (props) {
  return props.alignVertically ? 'center' : props.alignBottom ? 'end' : 'start';
}, function (props) {
  return props.justifyCenter ? 'center' : 'stretch';
}, function (props) {
  return props.tabletPadding ? props.tabletPadding : props.padding;
}, function (props) {
  return props.tabletWidth ? "".concat(props.tabletWidth, "%") : 'auto';
}, function (props) {
  return props.tabletSplit ? props.tabletSplit : props.split ? props.split : '1fr 1fr';
}, function (props) {
  return props.tabletGap ? props.tabletGap : props.gap ? props.gap : '0';
}, function (props) {
  return props.mobilePadding ? props.mobilePadding : props.padding;
}, function (props) {
  return props.mobileSplit ? props.mobileSplit : props.split ? props.split : '1fr 1fr';
}, function (props) {
  return props.mobileGap ? props.mobileGap : props.gap ? props.gap : '0';
}, function (props) {
  return props.mobileWidth ? "".concat(props.mobileWidth, "%") : 'auto';
});
/** ************************************************/

/** ***************** FONT STYLING *****************/

/** ************************************************/

/**
 * H1 Component
 * @type h1
 */

exports.GridSection = GridSection;

var H1 = _styledComponents.default.h1.withConfig({
  displayName: "global__H1",
  componentId: "wozf93-2"
})(["color:", ";font-weight:", ";font-size:", "px;text-transform:", ";margin-bottom:", ";line-height:", ";"], function (props) {
  return props.color ? _variables.COLORS[props.color] : props.colorRGBA ? props.colorRGBA : _variables.COLORS.dark;
}, function (props) {
  return props.weight ? props.weight : 800;
}, _variables.FONT.size * 3.25, function (props) {
  return props.uppercase ? 'uppercase' : 'none';
}, function (props) {
  return props.marginBottom ? '8px' : '0';
}, function (props) {
  return props.lineHeight ? "".concat(props.lineHeight, "%") : '100%';
});
/**
 * H2 Component
 * @type h2
 */


exports.H1 = H1;

var H2 = _styledComponents.default.h2.withConfig({
  displayName: "global__H2",
  componentId: "wozf93-3"
})(["color:", ";font-weight:", ";font-size:", "px;text-transform:", ";margin-bottom:", ";line-height:", ";"], function (props) {
  return props.color ? _variables.COLORS[props.color] : props.colorRGBA ? props.colorRGBA : _variables.COLORS.dark;
}, function (props) {
  return props.weight ? props.weight : 700;
}, _variables.FONT.size * 2.75, function (props) {
  return props.uppercase ? 'uppercase' : 'none';
}, function (props) {
  return props.marginBottom ? '8px' : '0';
}, function (props) {
  return props.lineHeight ? "".concat(props.lineHeight, "%") : '100%';
});
/**
 * H3 Component
 * @type h3
 */


exports.H2 = H2;

var H3 = _styledComponents.default.h3.withConfig({
  displayName: "global__H3",
  componentId: "wozf93-4"
})(["color:", ";font-weight:", ";font-size:", "px;text-transform:", ";margin-bottom:", ";line-height:", ";"], function (props) {
  return props.color ? _variables.COLORS[props.color] : props.colorRGBA ? props.colorRGBA : _variables.COLORS.dark;
}, function (props) {
  return props.weight ? props.weight : 700;
}, _variables.FONT.size * 2, function (props) {
  return props.uppercase ? 'uppercase' : 'none';
}, function (props) {
  return props.marginBottom ? '8px' : '0';
}, function (props) {
  return props.lineHeight ? "".concat(props.lineHeight, "%") : '100%';
});
/**
 * H4 Component
 * @type h4
 */


exports.H3 = H3;

var H4 = _styledComponents.default.h4.withConfig({
  displayName: "global__H4",
  componentId: "wozf93-5"
})(["color:", ";font-weight:", ";font-size:", "px;text-transform:", ";margin-bottom:", ";line-height:", ";"], function (props) {
  return props.color ? _variables.COLORS[props.color] : props.colorRGBA ? props.colorRGBA : _variables.COLORS.dark;
}, function (props) {
  return props.weight ? props.weight : 600;
}, _variables.FONT.size * 1.5, function (props) {
  return props.uppercase ? 'uppercase' : 'none';
}, function (props) {
  return props.marginBottom ? '8px' : '0';
}, function (props) {
  return props.lineHeight ? "".concat(props.lineHeight, "%") : '100%';
});
/**
 * H5 Component
 * @type h5
 */


exports.H4 = H4;

var H5 = _styledComponents.default.h5.withConfig({
  displayName: "global__H5",
  componentId: "wozf93-6"
})(["color:", ";font-weight:", ";font-size:", "px;text-transform:", ";margin-bottom:", ";line-height:", ";"], function (props) {
  return props.color ? _variables.COLORS[props.color] : props.colorRGBA ? props.colorRGBA : _variables.COLORS.dark;
}, function (props) {
  return props.weight ? props.weight : 600;
}, _variables.FONT.size * 1.25, function (props) {
  return props.uppercase ? 'uppercase' : 'none';
}, function (props) {
  return props.marginBottom ? '8px' : '0';
}, function (props) {
  return props.lineHeight ? "".concat(props.lineHeight, "%") : '100%';
});
/**
 * Text Component
 * @type p (paragraph)
 */


exports.H5 = H5;

var Text = _styledComponents.default.p.withConfig({
  displayName: "global__Text",
  componentId: "wozf93-7"
})(["color:", ";font-weight:", ";font-size:", "px;text-transform:", ";margin-bottom:", ";font-style:", ";text-align:", ";margin-top:", ";margin-bottom:", ";line-height:", ";strong{font-weight:700;}"], function (props) {
  return props.color ? _variables.COLORS[props.color] : props.colorRGBA ? props.colorRGBA : _variables.COLORS.dark;
}, function (props) {
  return props.weight ? props.weight : 400;
}, _variables.FONT.size * 3.25, function (props) {
  return props.uppercase ? 'uppercase' : 'none';
}, function (props) {
  return props.marginBottom ? '8px' : '0';
}, function (props) {
  return props.italic ? 'italic' : 'none';
}, function (props) {
  return props.align;
}, function (props) {
  return props.marginTop ? '8px' : '0';
}, function (props) {
  return props.marginBottom ? '8px' : '0';
}, function (props) {
  return props.lineHeight ? "".concat(props.lineHeight, "%") : '150%';
});

exports.Text = Text;
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(Section, "Section", "/Users/user1/Documents/projects/proponents/src/helpers/global.js");
  reactHotLoader.register(GridSection, "GridSection", "/Users/user1/Documents/projects/proponents/src/helpers/global.js");
  reactHotLoader.register(H1, "H1", "/Users/user1/Documents/projects/proponents/src/helpers/global.js");
  reactHotLoader.register(H2, "H2", "/Users/user1/Documents/projects/proponents/src/helpers/global.js");
  reactHotLoader.register(H3, "H3", "/Users/user1/Documents/projects/proponents/src/helpers/global.js");
  reactHotLoader.register(H4, "H4", "/Users/user1/Documents/projects/proponents/src/helpers/global.js");
  reactHotLoader.register(H5, "H5", "/Users/user1/Documents/projects/proponents/src/helpers/global.js");
  reactHotLoader.register(Text, "Text", "/Users/user1/Documents/projects/proponents/src/helpers/global.js");
  leaveModule(module);
})();

;